#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_ALMOST_EQUAL_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_ALMOST_EQUAL_HPP_INCLUDED

#include <nt2/fuzzy/include/functions/scalar/almost_equal.hpp>

#endif
